@@ -44,8 +44,7 @@ static GtkTreeView *setup_make_view(PersonalLauncherSetup *setup)
 	/*setup->entryList=gtk_list_store_new(4,GDK_TYPE_PIXBUF,G_TYPE_STRING,G_TYPE_STRING,G_TYPE_STRING);*/
 
 	keyFile=g_key_file_new();
-	filename=g_strdup(HOME_DIR);
-	filename=g_strconcat(filename,"/.personal_launcher.rc",NULL);
+	filename=g_build_filename(HOME_DIR,"/.personal_launcher.rc",NULL);
 	fileExists=g_key_file_load_from_file(keyFile,filename,G_KEY_FILE_KEEP_COMMENTS,NULL);
 	if (fileExists)
 	{
@@ -70,10 +69,10 @@ static GtkTreeView *setup_make_view(PersonalLauncherSetup *setup)
 	    executable=g_key_file_get_string(keyFile,entry,"executable",NULL);
 	    runAsRoot=g_key_file_get_string(keyFile,entry,"run as root",NULL);
 	    if (runAsRoot==NULL)
-		runAsRoot="false";
+			runAsRoot="false";
 	    runInTerm=g_key_file_get_string(keyFile,entry,"run in term",NULL);
 	    if (runInTerm==NULL)
-		runInTerm="false";
+			runInTerm="false";
 	    service=g_key_file_get_string(keyFile,entry,"service",NULL);
 
 	    icon_theme = gtk_icon_theme_get_default ();
@@ -96,6 +95,8 @@ static GtkTreeView *setup_make_view(PersonalLauncherSetup *setup)
 	    g_object_unref(G_OBJECT(icon));
 	    snprintf(entry,5,"%d",++i);
 	    found=g_key_file_has_group(keyFile,entry);
+	    g_free(runInTerm);
+	    g_free(runAsRoot);
 	  }
 	}
 	g_key_file_free(keyFile);
@@ -104,7 +105,7 @@ static GtkTreeView *setup_make_view(PersonalLauncherSetup *setup)
 	res = GTK_TREE_VIEW(gtk_tree_view_new_with_model(GTK_TREE_MODEL(setup->entryList)));
 	gtk_tree_view_append_column(res,gtk_tree_view_column_new_with_attributes(NULL,gtk_cell_renderer_pixbuf_new(),"pixbuf",0,NULL));
 	gtk_tree_view_append_column(res,gtk_tree_view_column_new_with_attributes(NULL,gtk_cell_renderer_text_new(),"text",1,NULL));
-	//gtk_tree_view_append_column(res,gtk_tree_view_column_new_with_attributes(NULL,gtk_cell_renderer_text_new(),"text",2,NULL));
+
 	gtk_tree_selection_set_mode(gtk_tree_view_get_selection(res),GTK_SELECTION_BROWSE);
 
 	return res;
@@ -728,7 +729,7 @@ void write_key_file(PersonalLauncherSetup *setup)
 
 	g_key_file_set_string(keyFile,"config","icon size",gtk_combo_box_get_active_text(GTK_COMBO_BOX(setup->iconSizeCombo)));
 	g_key_file_set_integer(keyFile,"config","padding",hildon_number_editor_get_value(HILDON_NUMBER_EDITOR(setup->padding)));
-	g_key_file_set_integer(keyFile,"config","transparency",hildon_controlbar_get_value(HILDON_CONTROLBAR(setup->trans)));
+	g_key_file_set_integer(keyFile,"config","transparency",(int)(((hildon_volumebar_get_level(HILDON_VOLUMEBAR(setup->trans))*254)/100)+1));
 	g_key_file_set_boolean(keyFile,"config","animation",gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(setup->animation)));
 	g_key_file_set_boolean(keyFile,"config","auto layout",gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(setup->layoutCheck)));
 	g_key_file_set_integer(keyFile,"config","num cols",hildon_number_editor_get_value(HILDON_NUMBER_EDITOR(setup->numCols)));
@@ -874,8 +875,9 @@ void run_setup(GtkWindow *parent)
 	caption=hildon_caption_new(NULL,"Select icon size",setup->iconSizeCombo,NULL,HILDON_CAPTION_MANDATORY);
 	gtk_box_pack_start(GTK_BOX(vbox2),caption,FALSE,FALSE,0);
 
-	setup->trans=hildon_controlbar_new();
-	hildon_controlbar_set_range(HILDON_CONTROLBAR(setup->trans),1,255);
+	setup->trans=hildon_hvolumebar_new();
+	g_object_set(G_OBJECT(setup->trans),"has_mute",FALSE,NULL);
+	
 	caption=hildon_caption_new(NULL,"Icon opacity",setup->trans,NULL,HILDON_CAPTION_MANDATORY);
 	gtk_box_pack_start(GTK_BOX(vbox2),caption,FALSE,FALSE,0);
 	
@@ -984,7 +986,7 @@ void run_setup(GtkWindow *parent)
 			gtk_combo_box_set_active(GTK_COMBO_BOX(setup->iconSizeCombo),4);
 
 		hildon_number_editor_set_value(HILDON_NUMBER_EDITOR(setup->padding),padding);
-		hildon_controlbar_set_value(HILDON_CONTROLBAR(setup->trans),trans);
+		hildon_volumebar_set_level(HILDON_VOLUMEBAR(setup->trans),((double)trans/255)*100);
 		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(setup->animation),animation);
 		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(setup->layoutCheck),layoutBool);
 		hildon_number_editor_set_value(HILDON_NUMBER_EDITOR(setup->numCols),numberOfCols);
@@ -994,7 +996,7 @@ void run_setup(GtkWindow *parent)
 	else
 	{
 		gtk_combo_box_set_active(GTK_COMBO_BOX(setup->iconSizeCombo),4);
-		hildon_controlbar_set_value(HILDON_CONTROLBAR(setup->trans),255);
+		hildon_volumebar_set_level(HILDON_VOLUMEBAR(setup->trans),100);
 		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(setup->animation),TRUE);
 		hildon_number_editor_set_value(HILDON_NUMBER_EDITOR(setup->padding),1);
 		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(setup->layoutCheck),TRUE);
